pyngrok Coverage Report

# pyngrok Coverage Report: 93.25%

Hot-keys on this page

n s m x c change column sorting

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
Total | 563 | 38 | 20 | 93.25%
pyngrok/__init__.py | 0 | 0 | 0 | 100.00%
pyngrok/conf.py | 28 | 0 | 0 | 100.00%
pyngrok/exception.py | 28 | 0 | 0 | 100.00%
pyngrok/installer.py | 128 | 6 | 4 | 95.31%
pyngrok/ngrok.py | 172 | 16 | 6 | 90.70%
pyngrok/process.py | 207 | 16 | 10 | 92.27%

No items found using the specified filter.